Release Notes
=============

0.2.5 (2023-03-09)
-------------------

- Added pyyaml dependency.
- Added tox and githib actions for automated testing.

0.2.4 (2023-03-08)
-------------------

- Started keeping track of changes in this file.
- Fixed an error with the license.
- Added the *unvanish* function to the toolset.
- Renamed *local_context* to *context* (README.rst was right all along).
- New supported file types for context: .yaml, .toml, .ini, .json
